package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.LogMapper;
import com.datacloudsec.scan.service.IConfig;
import com.datacloudsec.scan.service.ILog;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SecretUtil;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.io.FileUtils;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/LogService.class */
public class LogService implements ILog {
    private LogMapper logMapper = (LogMapper) InstanceUtil.newDaoInstance(LogMapper.class);
    private IConfig config = (IConfig) InstanceUtil.newServiceInstance(ConfigService.class);
    public static final String AESKEY = "asyscan002";

    public int queryCount(String begintime, String endtime, String username, Integer status, String event, String ip) throws Exception {
        return this.logMapper.searchCount(username, event, ip, status, begintime, endtime);
    }

    public List<Map<String, Object>> query(String begintime, String endtime, String username, Integer status, String event, String ip, Integer offset, Integer limit) throws Exception {
        return this.logMapper.search(username, event, ip, status, begintime, endtime, offset, limit);
    }

    public int clearLog(String clearDate) throws Exception {
        return this.logMapper.clearLog(clearDate);
    }

    public Map<String, Object> logUpper() throws Exception {
        Map<String, Object> map = new HashMap<>();
        map.put("log_max", Integer.valueOf(queryCount(null, null, null, null, null, null)));
        map.put("log_config_max", Integer.valueOf(ObjectUtil.getInt(this.config.getValueByName("logMax"), 0)));
        return map;
    }

    public File backup(String beginTime, String endTime) throws Exception {
        File f = new File(Constant.WORK_DIR, String.valueOf(System.currentTimeMillis()) + "_.logback");
        File faes = new File(Constant.WORK_DIR, String.valueOf(new SimpleDateFormat("yyyy年MM月dd日HH时mm分ss秒_S").format(new Date())) + ".logback");
        if (!f.exists()) {
            f.createNewFile();
        }
        if (!faes.exists()) {
            faes.createNewFile();
        }
        List<String> logdata = new ArrayList<>();
        for (Map<String, Object> log : this.logMapper.getLogsByDate(beginTime, endTime)) {
            if (MapUtils.isNotEmpty(log)) {
                logdata.add(JsonUtil.MAPPER.writeValueAsString(log));
            }
        }
        FileUtils.writeLines(f, logdata);
        SecretUtil.symmetryEncryptFile(f, faes, "aes", AESKEY);
        f.delete();
        return faes;
    }

    public void insert(String username, String event, String ip, Integer status, String desct) throws Exception {
        this.logMapper.insert(username, event, ip, status, desct);
    }

    @Transactional
    public void restore(File f) throws Exception {
        File aesdecode = new File(Constant.TEMP_DIR, String.valueOf(System.currentTimeMillis()) + ".logback");
        SecretUtil.decryptEncryptFile(f, aesdecode, "aes", AESKEY);
        List<String> lines = FileUtils.readLines(aesdecode);
        try {
            for (String l : lines) {
                Map<String, Object> line = (Map) JsonUtil.MAPPER.readValue(l, Map.class);
                if (!MapUtils.isEmpty(line)) {
                    insertAllParam(ObjectUtil.getLong(line.get("id"), 0L), ObjectUtil.getString(line.get("username"), ""), ObjectUtil.getString(line.get("event"), ""), ObjectUtil.getString(line.get("ip"), ""), Integer.valueOf(ObjectUtil.getInt(line.get("status"), 0)), ObjectUtil.getString(line.get("desct"), ""), ObjectUtil.getString(line.get("date"), ""));
                }
            }
        } finally {
            f.delete();
            aesdecode.delete();
        }
    }

    public void insertAllParam(Long id, String username, String event, String ip, Integer status, String desct, String date) throws Exception {
        this.logMapper.insertAllParam(id, username, event, ip, status, desct, date);
    }

    public void delLogById(Integer id) throws Exception {
        this.logMapper.delLogById(id);
    }
}
